@@ -9,9 +9,11 @@ from queue import Queue, Full
 from threading import Thread, Event
 from typing import TYPE_CHECKING
 
+
+
 from fast_tracker import config, plugins, loggings
-from fast_tracker.loggings import logger
 from fast_tracker.agent.protocol import Protocol
+from fast_tracker.utils import functions
 
 if TYPE_CHECKING:
     from fast_tracker.trace.context import Segment
@@ -61,13 +63,13 @@ def __fini():
 
 
 def start():
-    print("FAST: Config.Enable is %s " % config.enable)
+    functions.log("Config.Enable is %r ", config.enable)
     # 如果探针开关关闭,则不执行探针的初始化操作，不启动探针
     if not config.enable:
         return False
 
     if not config.product_code or not config.app_code:
-        print("FAST: 缺少product_code或app_code字段值，探针初始化失败")
+        functions.log("缺少product_code或app_code字段值，探针初始化失败")
         return False
 
     flag = False
@@ -77,7 +79,7 @@ def start():
 
         flag = monkey.is_module_patched("socket")
     except ImportError:  # ImportError python2\3都可以使用，ModuleNotFoundError只能用于3.6+
-        print("FAST: 未发现使用gevent，如果确实未使用gevent，请忽略。")
+        functions.log("未发现使用gevent，如果确实未使用gevent，请忽略。")
 
     if flag:
         import grpc.experimental.gevent as grpc_gevent
@@ -85,7 +87,7 @@ def start():
         grpc_gevent.init_gevent()
     global __started
     if __started:
-        print("FAST: 此代理只能启动一次")
+        functions.log("此代理只能启动一次")
         return False
     # 初始化log模块
     loggings.init()
@@ -100,6 +102,15 @@ def start():
     __report_thread.start()
     # atexit：退出处理器
     atexit.register(__fini)
+    # 打印配置
+    functions.log(
+        "探针enable配置为：%r, debug配置为：%r， logging_level配置为：%r， debug_level配置为：%r, config_path配置为：%r",
+        config.enable,
+        config.debug,
+        config.logging_level,
+        config.debug_level,
+        config.config_file,
+    )
 
 
 def stop():
@@ -120,5 +131,5 @@ def archive(segment: "Segment"):
     try:  # unlike checking __queue.full() then inserting, this is atomic
         __queue.put(segment, block=False)
     except Full:
-        print("队列已满，该segment将被放弃!")
+        functions.log("队列已满，该segment将被放弃!")
         # logger.warning("队列已满，该segment将被放弃!")
