@@ -8,6 +8,7 @@
 from fast_tracker import config, Layer, ComponentType, Log, LogItem
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
+from fast_tracker.utils import functions
 
 
 class FastTracker:
@@ -223,9 +224,11 @@ class FastTracker:
         """
         try:
             if "custom_event" in config.disable_plugins:
-                raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+                functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+                return False
             if not operation:
-                raise RuntimeError("operation参数必填")
+                functions.log("operation参数必填")
+                return False
             context = get_context()
             self.span = context.new_local_span(op="execute")
             self.span.layer = Layer.Local
@@ -237,34 +240,66 @@ class FastTracker:
             raise e
 
     def set_component(self, name: str = "CustomEvent"):
+        if type(name) is not str:
+            functions.log("传入参数类型不匹配，只允许传入str类型参数")
+            return False
+        if not name:
+            functions.log("name为空")
+            return False
         if "custom_event" in config.disable_plugins:
-            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+            functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+            return False
         if not self.span:
-            raise RuntimeError("请先调用begin_span进行实例化")
+            functions.log("请先调用begin_span进行实例化")
+            return False
         self.span.component = name
 
     def add_tag(self, key: str = "", val: str = ""):
+        if type(key) is not str or type(val) is not str:
+            functions.log("传入参数类型不匹配，只允许传入str类型参数")
+            return False
+        if not key or not val:
+            functions.log("key或val为空")
+            return False
         if "custom_event" in config.disable_plugins:
-            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+            functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+            return False
         if not self.span:
-            raise RuntimeError("请先调用begin_span进行实例化")
+            functions.log("请先调用begin_span进行实例化")
+            return False
         try:
             self.span.tag(Tag(key=key, val=val, overridable=True))
         except Exception as e:
             raise e
 
     def add_log(self, message: str = ""):
+        if type(message) is not str:
+            functions.log("传入参数类型不匹配，只允许传入str类型参数")
+            return False
+        if not message:
+            functions.log("message为空")
+            return False
         if "custom_event" in config.disable_plugins:
-            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+            functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+            return False
         if not self.span:
-            raise RuntimeError("请先调用begin_span进行实例化")
+            functions.log("请先调用begin_span进行实例化")
+            return False
         self.span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(message, err_type=""))]))
 
     def error_occurred(self, error: Exception):
+        if not error:
+            functions.log("参数为空")
+            return False
+        if type(error) is not Exception:
+            functions.log("传入参数类型不匹配，只允许传入Exception类型参数")
+            return False
         if "custom_event" in config.disable_plugins:
-            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+            functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+            return False
         if not self.span:
-            raise RuntimeError("请先调用begin_span进行实例化")
+            functions.log("请先调用begin_span进行实例化")
+            return False
         self.span.log(error)
 
     def log_covert(self, msg: str = "", err_type: str = "DEBUG"):
@@ -276,9 +311,11 @@ class FastTracker:
         :return:
         """
         if "custom_event" in config.disable_plugins:
-            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
+            functions.log("已在配置Event-Components-CustomEvent中关闭此项")
+            return False
         if not self.span:
-            raise RuntimeError("请先调用begin_span进行实例化")
+            functions.log("请先调用begin_span进行实例化")
+            return False
         self.span.stop()
 
     log_level = {"NOTSET": 0, "DEBUG": 10, "INFO": 20, "WARNING": 30, "ERROR": 40, "CRITICAL": 50}
@@ -303,18 +340,26 @@ class FastTracker:
 
     def __logging(self, msg: str = "", err_type: str = ""):
         try:
+            if not msg:
+                functions.log("参数为空")
+                return False
+            if type(msg) is not str:
+                functions.log("传入参数类型不匹配，只允许传入str类型参数")
+                return False
             config_log_type = FastTracker.log_level.get(config.logging_level)
             cus_log_type = FastTracker.log_level.get(err_type)
             if config_log_type > cus_log_type:
                 return False
             if "fast_log" in config.disable_plugins:
-                raise RuntimeError("已在配置Event-Components-Logging中关闭此项")
+                functions.log("已在配置Event-Components-Logging中关闭此项")
+                return False
             context = get_context()
             if not context:
-                raise RuntimeError("探针未启动")
+                functions.log("探针未启动")
+                return False
             with context.new_local_span(op="Logging") as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
                 span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(msg, err_type=err_type))]))
         except Exception as e:
-            raise e
+            functions.log("__logging发生错误，错误信息:%r", str(e))
