@@ -28,11 +28,13 @@ def install():
         carrier = Carrier()
         headers = get_headers(env)
         trace_id_name = config.get_trace_id_name()
+        trace_id_name = trace_id_name.replace("_", "-") if "_" in trace_id_name else trace_id_name
         for item in carrier:
-            if item.key.capitalize() in headers:
-                item.val = headers[item.key.capitalize()]
-            if item.key.upper() in headers:
-                item.val = headers[item.key.upper()]
+            key = item.key.replace("_", "-") if "_" in item.key else item.key
+            if key.capitalize() in headers:
+                item.val = headers[key.capitalize()]
+            if key.upper() in headers:
+                item.val = headers[key.upper()]
             if trace_id_name.capitalize() in headers and type(item) is Carrier:
                 item.set_frontend_trace_id(headers[trace_id_name.capitalize()])
             if trace_id_name.upper() in headers and type(item) is Carrier:
@@ -41,14 +43,8 @@ def install():
             span.layer = Layer.Http
             span.component = ComponentType.Falcon
 
-            resp = _original_falcon_api(this, env, start_response)
-
             from falcon import RequestOptions
-            from falcon import ResponseOptions
-
             req = request.Request(env, RequestOptions())
-            resp_obj = response.Response(ResponseOptions())
-
             span.op = str(req.url).split("?")[0]
             span.peer = "%s:%s" % (req.remote_addr, req.port)
             span.tag(Tag(key=tags.HttpMethod, val=req.method))
@@ -63,6 +59,12 @@ def install():
             set_code(config.user_code_reader, req, "user_code")
             set_code(config.env_code_reader, req, "env_code")
 
+            resp = _original_falcon_api(this, env, start_response)
+
+            from falcon import ResponseOptions
+
+            resp_obj = response.Response(ResponseOptions())
+
             resp_status = parse_status(resp_obj.status)
             if int(resp_status[0]) >= 400:
                 span.error_occurred = True
