@@ -91,6 +91,7 @@ def _gen_fast_get_response_func(old_execute):
             context = get_context()
             carrier = Carrier()
             trace_id_name = config.get_trace_id_name()
+            trace_id_name = trace_id_name.replace("_", "-") if "_" in trace_id_name else trace_id_name
             for item in carrier:
                 if item.key.capitalize() in request.headers:
                     item.val = request.headers[item.key.capitalize()]
@@ -115,8 +116,16 @@ def _gen_fast_get_response_func(old_execute):
                             self.request.headers.get("X-Forwarded-For") or \
                             self.request.remote_ip  # ::1
                     pass
+                temp_args = request.arguments
+                temp_arg = []
+                for key, arg in temp_args.items():
+                    val = []
+                    for i in arg:
+                        val.append(i.decode("utf-8"))
+                    temp_arg.append(str(key) + "=" + ",".join(val))
+                temp_arg = "&".join(temp_arg)
                 span.tag(Tag(key=tags.HttpMethod, val=request.method))
-                span.tag(Tag(key=tags.HttpUrl, val="{}://{}{}".format(request.protocol, request.host, request.path)))
+                span.tag(Tag(key=tags.HttpUrl, val="{}://{}{}?{}".format(request.protocol, request.host, request.path, temp_arg)))
                 result = yield from old_execute(self, *args, **kwargs)
                 span.tag(Tag(key=tags.HttpStatus, val=self._status_code, overridable=True))
                 if self._status_code >= 400:
@@ -146,37 +155,44 @@ def set_code(reader, request, code_type="tenant_code"):
 
     reader_type = reader.get("ReaderType")
     reader_key = reader.get("ReaderKey")
+    try:
+        if reader_type == ReaderType.Cookie:
+            # # tornado6.0.4 is ok
+            # code = request.get_cookie(reader_key, "")
+            # tornado5.1.1 is ok
+            # code: Set-Cookie: env_c=gog <Morsel: env_c=gog>
+            # request.cookies is A dictionary of Cookie.Morsel objects
+            # tornado5.1.1 source code->tornado-httputil.py-HTTPServerRequest-cookies
+            cookie = request.cookies.get(reader_key, "")
+            if type(cookie) == str:
+                code = cookie
+            else:
+                code = request.cookies.get(reader_key, "").value
+            # code = request.cookies.get(reader_key, "").value
+        elif reader_type == ReaderType.RequestHeader:
+            code = request.headers[reader_key] if reader_key in request.headers else ""
+        elif reader_type == ReaderType.QueryString:
+            # data = json.loads(request.body.decode('utf-8'))
+            # # tornado6.0.4 is ok
+            # code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
+            # tornado5.1.1
+            arg = request.arguments.get(reader_key)
+            code = arg[0].decode("utf-8") if type(arg) == list else ""
+        elif reader_type == ReaderType.Environment:
+            import os
 
-    if reader_type == ReaderType.Cookie:
-        # # tornado6.0.4 is ok
-        # code = request.get_cookie(reader_key, "")
-        # tornado5.1.1 is ok
-        # code: Set-Cookie: env_c=gog <Morsel: env_c=gog>
-        # request.cookies is A dictionary of Cookie.Morsel objects
-        # tornado5.1.1 source code->tornado-httputil.py-HTTPServerRequest-cookies
-        code = request.cookies.get(reader_key, "").value
-    elif reader_type == ReaderType.RequestHeader:
-        code = request.headers[reader_key] if reader_key in request.headers else ""
-    elif reader_type == ReaderType.QueryString:
-        # data = json.loads(request.body.decode('utf-8'))
-        # # tornado6.0.4 is ok
-        # code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
-        # tornado5.1.1
-        arg = request.arguments.get(reader_key)
-        code = arg[0].decode("utf-8") if type(arg) == list else ""
-    elif reader_type == ReaderType.Environment:
-        import os
+            code = os.getenv(reader.get("ReaderKey"), "")
+        else:
+            code = ""
 
-        code = os.getenv(reader.get("ReaderKey"), "")
-    else:
-        code = ""
-
-    # 设置用户自定义字段值
-    if code_type == "tenant_code" and not config.custom_tenant_code:
-        config.custom_tenant_code = code
-    elif code_type == "user_code" and not config.custom_user_code:
-        config.custom_user_code = code
-    elif code_type == "env_code" and not config.custom_env_code:
-        config.custom_env_code = code
+        # 设置用户自定义字段值
+        if code_type == "tenant_code" and not config.custom_tenant_code:
+            config.custom_tenant_code = code
+        elif code_type == "user_code" and not config.custom_user_code:
+            config.custom_user_code = code
+        elif code_type == "env_code" and not config.custom_env_code:
+            config.custom_env_code = code
+    except BaseException as e:
+        functions.log("tornado 获取code错误，错误信息: %r", str(e))
 
     return code
